>From 644753cd1a0556291dcbfd21cd881ec075de23c9 Mon Sep 17 00:00:00 2001
From: Marc Haber <mh+debian-packages@zugschlus.de>
Date: Sat, 9 Jan 2016 17:01:11 +0100
Subject: [PATCH 1/2] add exclude-stage1-path option

---
 debootstrap   | 15 +++++++++++++++
 debootstrap.8 |  4 ++++
 functions     |  2 +-
 scripts/sid   |  4 ++++
 4 files changed, 24 insertions(+), 1 deletion(-)

diff --git a/debootstrap b/debootstrap
index 2a959bb..fe4de7b 100755
--- a/debootstrap
+++ b/debootstrap
@@ -46,6 +46,7 @@ VERBOSE=""
 CERTIFICATE=""
 CHECKCERTIF=""
 PRIVATEKEY=""
+EXCLUDE_STAGE1_PATH=""
 
 DEF_MIRROR="http://httpredir.debian.org/debian"
 DEF_HTTPS_MIRROR="https://mirrors.kernel.org/debian"
@@ -121,6 +122,9 @@ usage()
       --private-key=file     read the private key from file
       --certificate=file     use the client certificate stored in file (PEM)
       --no-check-certificate do not check certificate against certificate authorities
+      
+      --exclude-stage1-path=PATH,PATH do not install anything to PATH and PATH in
+                             stage 1
 EOF
 }
 
@@ -352,6 +356,17 @@ if [ $# != 0 ] ; then
 		CHECKCERTIF="--no-check-certificate"
 		shift
 		;;
+	    --exclude-stage1-path|--exclude-stage1-path=?*)
+		if [ "$1" = "--exclude-stage1-path" -a -n "$2" ]; then
+			EXCLUDE_STAGE1_PATH="$2"
+			shift 2
+		elif [ "$1" != "${1#--exclude-stage1-path=}" ]; then
+			EXCLUDE_STAGE1_PATH="${1#--exclude-stage1-path=}" 
+			shift 1
+		else
+		       error 1 NEEDARG "option requires an argument %s" "$1" 
+		fi
+		;;
 	    --*)
 		error 1 BADARG "unrecognized or invalid option %s" "$1"
 		;;
diff --git a/debootstrap.8 b/debootstrap.8
index 5864148..c8f0722 100644
--- a/debootstrap.8
+++ b/debootstrap.8
@@ -156,6 +156,10 @@ Use the client certificate stored in file (PEM)
 .IP
 .IP "\fB\-\-private\-key=FILE\fP"
 Read the private key from file
+.IP
+.IP "\fB\-\-exclude\-stage1\-path=PATH,PATH\fP"
+Exclude the paths listed in the comma separated from being unpacked
+during stage 1.
 
 .SH EXAMPLES
 .
diff --git a/functions b/functions
index 8bef5e6..76c1eae 100644
--- a/functions
+++ b/functions
@@ -807,7 +807,7 @@ extract_dpkg_deb_field () {
 extract_dpkg_deb_data () {
 	local pkg="$1"
 
-	dpkg-deb --fsys-tarfile "$pkg" | tar -xf -
+	dpkg-deb --fsys-tarfile "$pkg" | tar --extract $TAR_OPTS --file -
 }
 
 # Raw .deb extractors
diff --git a/scripts/sid b/scripts/sid
index bf3404f..fd0666a 100644
--- a/scripts/sid
+++ b/scripts/sid
@@ -4,6 +4,10 @@ finddebs_style from-indices
 variants - buildd fakechroot minbase scratchbox
 keyring /usr/share/keyrings/debian-archive-keyring.gpg
 
+if [ -n "$EXCLUDE_STAGE1_PATH" ]; then
+  TAR_OPTS="$TAR_OPTS --exclude=.$(echo $EXCLUDE_STAGE1_PATH | sed 's|,| --exclude=.|g')"
+fi
+
 if doing_variant fakechroot; then
 	test "$FAKECHROOT" = "true" || error 1 FAKECHROOTREQ "This variant requires fakechroot environment to be started"
 fi
-- 
2.7.0.rc3

